# Generated by Django 4.0.4 on 2022-04-25 11:35

from django.conf import settings
from django.db import migrations, models


def copy_tutor_examiner(apps, schema_editor):
    # get models
    LabUser = apps.get_model("api", "LabUser")
    Tutor = apps.get_model("api", "Tutor")
    Examiner = apps.get_model("api", "Examiner")

    # loop all users
    for user in LabUser.objects.all():
        # set is_tutor
        is_tutor = Tutor.objects.filter(user_id=user.id).count() > 0
        is_examiner = Examiner.objects.filter(user_id=user.id).count() > 0

        # set it
        user.is_tutor = is_tutor
        user.is_examiner = is_examiner
        user.save()


def link_experiment_labuser(apps, schema_editor):
    # get models
    Experiment = apps.get_model("api", "Experiment")

    # loop experiments
    for exp in Experiment.objects.all():
        # migrate tutors
        tutor_ids = [t.user.id for t in exp.tutors_old.all()]
        exp.tutors.set(tutor_ids)

        # migrate examiners
        examiner_ids = [e.user.id for e in exp.examiners_old.all()]
        exp.examiners.set(examiner_ids)

        # save it
        exp.save()


class Migration(migrations.Migration):

    replaces = [
        ("api", "0005_labuser_is_examiner_labuser_is_tutor"),
        ("api", "0006_auto_20220425_1111"),
        ("api", "0007_rename_examiners_experiment_examiners_old_and_more"),
        ("api", "0008_alter_experiment_examiners_old_and_more"),
        ("api", "0009_experiment_examiners_experiment_tutors"),
        ("api", "0010_auto_20220425_1126"),
        ("api", "0011_remove_experiment_examiners_old_and_more"),
    ]

    dependencies = [
        ("api", "0004_remove_examiner_address_remove_examiner_institute_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="labuser",
            name="is_examiner",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="labuser",
            name="is_tutor",
            field=models.BooleanField(default=False),
        ),
        migrations.RunPython(copy_tutor_examiner),
        migrations.RenameField(
            model_name="experiment",
            old_name="examiners",
            new_name="examiners_old",
        ),
        migrations.RenameField(
            model_name="experiment",
            old_name="tutors",
            new_name="tutors_old",
        ),
        migrations.AlterField(
            model_name="experiment",
            name="examiners_old",
            field=models.ManyToManyField(blank=True, related_name="examiner_experiments_old", to="api.examiner"),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="tutors_old",
            field=models.ManyToManyField(blank=True, related_name="tutor_experiments_old", to="api.tutor"),
        ),
        migrations.AddField(
            model_name="experiment",
            name="examiners",
            field=models.ManyToManyField(blank=True, related_name="examiner_experiments", to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name="experiment",
            name="tutors",
            field=models.ManyToManyField(blank=True, related_name="tutor_experiments", to=settings.AUTH_USER_MODEL),
        ),
        migrations.RunPython(link_experiment_labuser),
        migrations.RemoveField(
            model_name="experiment",
            name="examiners_old",
        ),
        migrations.RemoveField(
            model_name="experiment",
            name="tutors_old",
        ),
        migrations.RemoveField(
            model_name="tutor",
            name="user",
        ),
        migrations.DeleteModel(
            name="Examiner",
        ),
        migrations.DeleteModel(
            name="Tutor",
        ),
    ]
