# Generated by Django 4.0.4 on 2023-03-20 13:26
# adapted from https://gist.github.com/ebsaral/51ce560c5ef98f42259348db213e693e

import LabCourse.api.models
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class CopyFieldsBetweenTables(migrations.operations.base.Operation):
    reversible = False

    def __init__(self, model_from_name, model_to_name, columns):
        self.model_from_name = model_from_name
        self.model_to_name = model_to_name
        self.columns = columns

    def state_forwards(self, app_label, state):
        pass

    def database_forwards(self, app_label, schema_editor, from_state, to_state):
        columns = ", ".join(self.columns)

        schema_editor.execute(
            f"""
            INSERT INTO {app_label}_{self.model_to_name}
            (temp_obj_name, temp_id, {columns})
            SELECT '{self.model_from_name}', id, {columns}
            FROM {app_label}_{self.model_from_name};"""
        )
        schema_editor.execute(
            f"""
            UPDATE {app_label}_{self.model_from_name}
              SET updatemodel_ptr_id = (
                SELECT id
                FROM {app_label}_{self.model_to_name} 
                WHERE temp_id={app_label}_{self.model_from_name}.id AND
                  temp_obj_name='{self.model_from_name}'  
                LIMIT 1
              );"""
        )

    def database_backwards(self, app_label, schema_editor, from_state, to_state):
        pass

    def describe(self):
        return "Copies between two tables for %s" % self.name


class Migration(migrations.Migration):

    dependencies = [
        ("api", "0056_partnersearch"),
    ]

    operations = [
        # Create the base class
        migrations.CreateModel(
            name="UpdateModel",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("date", models.DateTimeField(auto_now=True)),
                (
                    "type",
                    models.CharField(
                        choices=[
                            (
                                LabCourse.api.models.UpdateModel.Action["ADDED"],
                                LabCourse.api.models.UpdateModel.Action["ADDED"],
                            ),
                            (
                                LabCourse.api.models.UpdateModel.Action["CHANGED"],
                                LabCourse.api.models.UpdateModel.Action["CHANGED"],
                            ),
                            (
                                LabCourse.api.models.UpdateModel.Action["CLOSED"],
                                LabCourse.api.models.UpdateModel.Action["CLOSED"],
                            ),
                        ],
                        max_length=10,
                    ),
                ),
                ("comment", models.CharField(blank=True, max_length=50, null=True)),
                (
                    "user",
                    models.ForeignKey(
                        null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL
                    ),
                ),
            ],
            options={
                "ordering": ["date"],
            },
        ),
        # Add temporary holder fields
        migrations.AddField(
            model_name="updatemodel",
            name="temp_id",
            field=models.IntegerField(default=0, null=True, blank=True),
        ),
        migrations.AddField(
            model_name="updatemodel",
            name="temp_obj_name",
            field=models.CharField(max_length=255, null=True, blank=True),
        ),
        # Add pointer field as a foreign key first (then it will be converted to real reference).
        # By doing this, you prevent address_ptr being null issue
        migrations.AddField(
            model_name="appointmentupdate",
            name="updatemodel_ptr",
            field=models.ForeignKey("api.UpdateModel", models.CASCADE, null=True, blank=True),
        ),
        migrations.AddField(
            model_name="examupdate",
            name="updatemodel_ptr",
            field=models.ForeignKey("api.UpdateModel", models.CASCADE, null=True, blank=True),
        ),
        migrations.AddField(
            model_name="reportupdate",
            name="updatemodel_ptr",
            field=models.ForeignKey("api.UpdateModel", models.CASCADE, null=True, blank=True),
        ),
        # Copy data from to UpdateModel, and update relation fields
        CopyFieldsBetweenTables(
            model_from_name="appointmentupdate",
            model_to_name="updatemodel",
            columns=["date", "user_id", "type", "comment"],
        ),
        CopyFieldsBetweenTables(
            model_from_name="examupdate",
            model_to_name="updatemodel",
            columns=["date", "user_id", "type", "comment"],
        ),
        CopyFieldsBetweenTables(
            model_from_name="reportupdate",
            model_to_name="updatemodel",
            columns=["date", "user_id", "type", "comment"],
        ),
        # Remove temporary fields in UpdateModel
        migrations.RemoveField(model_name="updatemodel", name="temp_id"),
        migrations.RemoveField(model_name="updatemodel", name="temp_obj_name"),
        # Remove id fields from child classes, since we won't be using them anymore
        migrations.RemoveField(model_name="appointmentupdate", name="id"),
        migrations.RemoveField(model_name="examupdate", name="id"),
        migrations.RemoveField(model_name="reportupdate", name="id"),
        # Convert pointer field initially created to a OneToOneField
        migrations.AlterField(
            model_name="appointmentupdate",
            name="updatemodel_ptr",
            field=models.OneToOneField(
                parent_link=True,
                on_delete=models.deletion.CASCADE,
                auto_created=True,
                primary_key=True,
                serialize=False,
                to="api.UpdateModel",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="examupdate",
            name="updatemodel_ptr",
            field=models.OneToOneField(
                parent_link=True,
                on_delete=models.deletion.CASCADE,
                auto_created=True,
                primary_key=True,
                serialize=False,
                to="api.UpdateModel",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="reportupdate",
            name="updatemodel_ptr",
            field=models.OneToOneField(
                parent_link=True,
                on_delete=models.deletion.CASCADE,
                auto_created=True,
                primary_key=True,
                serialize=False,
                to="api.UpdateModel",
            ),
            preserve_default=False,
        ),
        # Remove copied fields which came from abstract base class
        migrations.RemoveField(
            model_name="appointmentupdate",
            name="comment",
        ),
        migrations.RemoveField(
            model_name="appointmentupdate",
            name="date",
        ),
        migrations.RemoveField(
            model_name="appointmentupdate",
            name="type",
        ),
        migrations.RemoveField(
            model_name="appointmentupdate",
            name="user",
        ),
        migrations.RemoveField(
            model_name="examupdate",
            name="comment",
        ),
        migrations.RemoveField(
            model_name="examupdate",
            name="date",
        ),
        migrations.RemoveField(
            model_name="examupdate",
            name="type",
        ),
        migrations.RemoveField(
            model_name="examupdate",
            name="user",
        ),
        migrations.RemoveField(
            model_name="reportupdate",
            name="comment",
        ),
        migrations.RemoveField(
            model_name="reportupdate",
            name="date",
        ),
        migrations.RemoveField(
            model_name="reportupdate",
            name="type",
        ),
        migrations.RemoveField(
            model_name="reportupdate",
            name="user",
        ),
    ]
