"""
Django settings for LabCourse project.

Generated by 'django-admin startproject' using Django 4.0.3.

For more information on this file, see
https://docs.djangoproject.com/en/4.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.0/ref/settings/
"""
import os
from pathlib import Path

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "django-insecure-q&+&i*lk$0!!yg7k%ckv4_nt@sq*8yh%x3v_@p84jj+-s7)pa="

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True
ALLOWED_HOSTS = ["localhost"]

# Application definition
INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "widget_tweaks",
    "djcelery_email",
    "LabCourse.mylab",
    "LabCourse.mylab_admin",
    "LabCourse.mylab_examiner",
    "LabCourse.mylab_tutor",
    "LabCourse.mylab_student",
    "LabCourse.frontend",
    "LabCourse.api",
    "LabCourse.openid",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]

AUTHENTICATION_BACKENDS = ("django.contrib.auth.backends.ModelBackend",)

ROOT_URLCONF = "LabCourse.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [BASE_DIR / "templates"],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "LabCourse.frontend.context_processors.labcourse",
            ],
        },
    },
]

WSGI_APPLICATION = "LabCourse.wsgi.application"

# Database
# https://docs.djangoproject.com/en/4.0/ref/settings/#databases

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": BASE_DIR / "db.sqlite3",
    }
}

# Password validation
# https://docs.djangoproject.com/en/4.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]

# Internationalization
# https://docs.djangoproject.com/en/4.0/topics/i18n/

LANGUAGE_CODE = "en-us"

TIME_ZONE = "UTC"

USE_I18N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.0/howto/static-files/

STATIC_URL = "static/"
STATIC_ROOT = os.path.join(BASE_DIR, "static")
SERVE_MEDIA = True
MEDIA_URL = "media/"
MEDIA_ROOT = os.path.join(BASE_DIR, "media/public/")
PRIVATE_MEDIA_ROOT = os.path.join(BASE_DIR, "media/private/")
REPORTS_URL = "reports/"
REPORTS_ROOT = os.path.join(BASE_DIR, "reports/")
INSTRUCTIONS_URL = "instructions/"
INSTRUCTIONS_ROOT = os.path.join(BASE_DIR, "instructions/")
ROOT_URL = "http://localhost:8000"

# Email

EMAIL_FROM = "Advanced Lab Course <alc.physics@uni-goettingen.de>"


# Default primary key field type
# https://docs.djangoproject.com/en/4.0/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

# SESSION_COOKIE_AGE = 36000

AUTH_USER_MODEL = "api.LabUser"

LOGIN_REDIRECT_URL = "/"
LOGOUT_REDIRECT_URL = "http://localhost:8000/"

# LabCourse settings
LABCOURSE = {
    "LOCAL_LOGIN": True,
    "REQUIRE_UPLOAD_REPORT": True,
    "REPORTS_PER_EXAM": 4,
    "STUDENT": {
        "CAN_JOIN": True,
        "CAN_REQUEST_APPOINTMENT": True,
        "CAN_CANCEL_APPOINTMENT_REQUEST": True,
        "CAN_UPLOAD_REPORT": True,
        "CAN_ADD_EXAM": True,
        "SEND_EMAIL_NEW_APPOINTMENT": False,
        "SEND_EMAIL_APPOINTMENT_CANCELED": False,
        "SEND_EMAIL_APPOINTMENT_CHANGED": False,
        "SEND_EMAIL_JOIN_REQUEST": False,
        "SEND_EMAIL_NEW_EXAM": False,
        "SEND_EMAIL_EXAM_CLOSED": False,
        "SEND_EMAIL_REPORT_ACCEPTED": False,
        "SEND_EMAIL_REPORT_UPLOADED": False,
        "SEND_EMAIL_EVALUATION_REQUEST": False,
    },
    "TUTOR": {
        "SEND_EMAIL_NEW_APPOINTMENT_REQUEST": False,
        "SEND_EMAIL_NEW_APPOINTMENT": False,
        "SEND_EMAIL_APPOINTMENT_CANCELED": False,
        "SEND_EMAIL_APPOINTMENT_CHANGED": False,
        "SEND_EMAIL_REPORT_ACCEPTED": False,
        "SEND_EMAIL_REPORT_UPLOADED": False,
    },
    "EXAMINER": {
        "SEND_EMAIL_NEW_EXAM": False,
        "SEND_EMAIL_EXAM_CLOSED": False,
    },
    "ADMIN": {
        "SEND_EMAIL_NEW_APPOINTMENT_REQUEST": False,
        "SEND_EMAIL_NEW_APPOINTMENT": False,
        "SEND_EMAIL_APPOINTMENT_CANCELED": False,
        "SEND_EMAIL_APPOINTMENT_CHANGED": False,
        "SEND_EMAIL_JOIN_REQUEST": False,
        "SEND_EMAIL_NEW_EXAM": False,
        "SEND_EMAIL_EXAM_CLOSED": False,
        "SEND_EMAIL_REPORT_ACCEPTED": False,
        "SEND_EMAIL_REPORT_UPLOADED": False,
        "SEND_EMAIL_EVALUATION_REQUEST": False,
        "SEND_EMAIL_EVALUATION": False,
    },
}

# try to import a local_settings.py
try:
    from .local_settings import *
except ImportError:
    pass
